@@ -9,7 +9,7 @@
 
 Usage:
   kibot [-b BOARD] [-e SCHEMA] [-c CONFIG] [-d OUT_DIR] [-s PRE]
-         [-q | -v...] [-i] [-C] [-m MKFILE] [-g DEF]... [TARGET...]
+         [-q | -v...] [-C | -i | -n] [-m MKFILE] [-g DEF]... [TARGET...]
   kibot [-v...] [-b BOARD] [-e SCHEMA] [-c PLOT_CONFIG] --list
   kibot [-v...] [-b BOARD] [-d OUT_DIR] [-p | -P] --example
   kibot [-v...] [--start PATH] [-d OUT_DIR] [--dry] [-t, --type TYPE]...
@@ -37,6 +37,7 @@ Options:
   -i, --invert-sel                 Generate the outputs not listed as targets
   -l, --list                       List available outputs (in the config file)
   -m MKFILE, --makefile MKFILE     Generate a Makefile (no targets created)
+  -n, --no-priority                Don't sort targets by priority
   -p, --copy-options               Copy plot options from the PCB file
   -P, --copy-and-expand            As -p but expand the list of layers
   -q, --quiet                      Remove information logs
@@ -213,6 +214,7 @@ def detect_kicad():
     # /usr/share/kicad/*
     GS.kicad_plugins_dirs.append(os.path.join(GS.kicad_share_path, 'scripting'))
     GS.kicad_plugins_dirs.append(os.path.join(GS.kicad_share_path, 'scripting', 'plugins'))
+    GS.kicad_plugins_dirs.append(os.path.join(GS.kicad_share_path, '3rdparty', 'plugins'))  # KiCad 6.0 PCM
     # ~/.config/kicad/*
     GS.kicad_plugins_dirs.append(os.path.join(GS.kicad_conf_path, 'scripting'))
     GS.kicad_plugins_dirs.append(os.path.join(GS.kicad_conf_path, 'scripting', 'plugins'))
@@ -222,6 +224,10 @@ def detect_kicad():
         GS.kicad_plugins_dirs.append(os.path.join(home, '.kicad_plugins'))
         GS.kicad_plugins_dirs.append(os.path.join(home, '.kicad', 'scripting'))
         GS.kicad_plugins_dirs.append(os.path.join(home, '.kicad', 'scripting', 'plugins'))
+        if GS.kicad_version_major >= 6:
+            # KiCad 6.0 PCM
+            ver_dir = str(GS.kicad_version_major)+'.'+str(GS.kicad_version_minor)
+            GS.kicad_plugins_dirs.append(os.path.join(home, '.local', 'share', 'kicad', ver_dir, '3rdparty', 'plugins'))
     if GS.debug_level > 1:
         logger.debug('KiCad config path {}'.format(GS.kicad_conf_path))
 
@@ -314,7 +320,7 @@ def main():
         generate_makefile(args.makefile, plot_config, outputs)
     else:
         # Do all the job (preflight + outputs)
-        generate_outputs(outputs, args.target, args.invert_sel, args.skip_pre, args.cli_order)
+        generate_outputs(outputs, args.target, args.invert_sel, args.skip_pre, args.cli_order, args.no_priority)
     # Print total warnings
     logger.log_totals()
 
