@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2020-2021 Salvador E. Tropea
-# Copyright (c) 2020-2021 Instituto Nacional de Tecnología Industrial
+# Copyright (c) 2020-2022 Salvador E. Tropea
+# Copyright (c) 2020-2022 Instituto Nacional de Tecnología Industrial
 # Copyright (c) 2016-2020 Oliver Henry Walters (@SchrodingersGat)
 # License: MIT
 # Project: KiBot (formerly KiPlot)
@@ -12,13 +12,14 @@ All the logic to convert a list of components into the rows and columns used to
 import locale
 from copy import deepcopy
 from math import ceil
-from .units import compare_values, comp_match
+from .units import compare_values, comp_match, get_last_warning
 from .bom_writer import write_bom
 from .columnlist import ColumnList
 from ..misc import DNF, W_FIELDCONF
+from ..gs import GS
 from .. import log
 
-logger = log.get_logger(__name__)
+logger = log.get_logger()
 # RV == Resistor Variable or Varistor
 # RN == Resistor 'N'(Pack)
 # RT == Thermistor
@@ -70,6 +71,9 @@ def compare_field(c1, c2, field, cfg):
     # If blank comparisons are allowed
     if (c1_value == "" or c2_value == "") and cfg.merge_blank_fields:
         return True
+    if not cfg.merge_both_blank and c1_value == "" and c2_value == "":
+        # Avoid merging two components with empty field
+        return False
     return c1_value == c2_value
 
 
@@ -178,7 +182,7 @@ class ComponentGroup(object):
     def add_component(self, c):
         """ Add a component to the group.
             Avoid repetition, checks if suitable.
-            Note: repeated components happend when a component contains more than one unit """
+            Note: repeated components happens when a component contains more than one unit """
         if not self.components:
             self.components.append(c)
             self.refs[c.ref+c.project] = c
@@ -222,9 +226,9 @@ class ComponentGroup(object):
             if self.cfg.source_by_id:
                 prj = self.cfg.source_to_id[prj]
             if prj in sources:
-                sources[prj] += 1
+                sources[prj] += c.qty
             else:
-                sources[prj] = 1
+                sources[prj] = c.qty
         field = ''
         for prj in sorted(sources.keys()):
             n = sources[prj]
@@ -241,6 +245,12 @@ class ComponentGroup(object):
         # compare_components ensures all has the same status
         return self.components[0].fixed
 
+    def is_smd(self):
+        return self.components[0].smd
+
+    def is_tht(self):
+        return self.components[0].tht
+
     def get_field(self, field):
         field = field.lower()
         if field not in self.fields or not self.fields[field]:
@@ -293,7 +303,8 @@ class ComponentGroup(object):
                     fld=value, ref=ref))
             self.fields[field] += " " + value
 
-    def update_fields(self, usealt=False):
+    def update_fields(self, conv, bottom_negative_x, x_origin, y_origin, angle_positive, footprint_populate_values,
+                      footprint_type_values, usealt=False):
         for c in self.components:
             for f, v in c.get_user_fields():
                 self.update_field(f, v, c.ref)
@@ -321,6 +332,25 @@ class ComponentGroup(object):
         self.fields[ColumnList.COL_PART_LIB_L] = comp.lib
         self.fields[ColumnList.COL_DATASHEET_L] = comp.datasheet
         self.fields[ColumnList.COL_FP_L] = comp.footprint
+        pos_x = (comp.footprint_x - x_origin) * conv
+        if bottom_negative_x and comp.bottom:
+            pos_x = -pos_x
+        self.fields[ColumnList.COL_FP_X_L] = "{:.4f}".format(pos_x)
+        self.fields[ColumnList.COL_FP_Y_L] = "{:.4f}".format(-(comp.footprint_y - y_origin) * conv)
+        rot = comp.footprint_rot
+        if angle_positive:
+            rot = rot % 360
+        self.fields[ColumnList.COL_FP_ROT_L] = "{:.4f}".format(rot)
+        self.fields[ColumnList.COL_FP_SIDE_L] = "bottom" if comp.bottom else "top"
+        type = 0
+        if comp.tht:
+            type = 1
+        if comp.virtual:
+            type = 2
+        self.fields[ColumnList.COL_FP_TYPE_L] = footprint_type_values[type]
+        self.fields[ColumnList.COL_FP_FIT_L] = footprint_populate_values[comp.fitted]
+        self.fields[ColumnList.COL_FP_XS_L] = "{:.4f}".format(comp.footprint_w * conv)
+        self.fields[ColumnList.COL_FP_YS_L] = "{:.4f}".format(comp.footprint_h * conv)
         self.fields[ColumnList.COL_FP_LIB_L] = comp.footprint_lib
         self.fields[ColumnList.COL_SHEETPATH_L] = comp.sheet_path_h
         if not self.fields[ColumnList.COL_DESCRIPTION_L]:
@@ -339,25 +369,27 @@ class ComponentGroup(object):
                 if elements > 1 and target == key:
                     # Append data from the other fields
                     for source in join_l[1:]:
-                        v = self.get_field(source)
+                        v = source.get_text(self.get_field)
                         if v:
-                            val = val + ' ' + v
+                            val += v
             row.append(val)
         return row
 
 
-def get_value_sort(comp):
+def get_value_sort(comp, fallback_ref=False):
     """ Try to better sort R, L and C components """
     res = comp.value_sort
     if res:
         value, (mult, mult_s), unit = res
         if comp.ref_prefix in "CL":
-            # fempto Farads
+            # femto Farads
             value = "{0:15d}".format(int(value * 1e15 * mult + 0.1))
         else:
             # milli Ohms
             value = "{0:15d}".format(int(value * 1000 * mult + 0.1))
         return value
+    if fallback_ref:
+        return comp.ref_prefix + "{0:15d}".format(_suffix_to_num(comp.ref_suffix))
     return comp.value
 
 
@@ -375,8 +407,8 @@ def normalize_value(c, decimal_point):
 
 def compute_multiple_stats(cfg, groups):
     for sch in cfg.aggregate:
-        sch.comp_total = 0
-        sch.comp_fitted = 0
+        sch.comp_total = sch.comp_total_smd = sch.comp_total_tht = 0
+        sch.comp_fitted = sch.comp_fitted_smd = sch.comp_fitted_tht = 0
         sch.comp_build = 0
         sch.comp_groups = 0
         for g in groups:
@@ -384,8 +416,16 @@ def compute_multiple_stats(cfg, groups):
             if g_l:
                 sch.comp_groups = sch.comp_groups+1
             sch.comp_total += g_l
+            if g.is_smd():
+                sch.comp_total_smd += g_l
+            if g.is_tht():
+                sch.comp_total_tht += g_l
             if g.is_fitted():
                 sch.comp_fitted += g_l
+                if g.is_smd():
+                    sch.comp_fitted_smd += g_l
+                if g.is_tht():
+                    sch.comp_fitted_tht += g_l
         sch.comp_build = sch.comp_fitted*sch.number
         if cfg.debug_level > 1:
             logger.debug('Stats for {}: total {} fitted {} build {}'.
@@ -400,7 +440,15 @@ def group_components(cfg, components):
             continue
         # Cache the value used to sort
         if c.ref_prefix in RLC_PREFIX and c.value.lower() not in DNF:
-            c.value_sort = comp_match(c.value, c.ref_prefix)
+            c.value_sort = comp_match(c.value, c.ref_prefix, c.ref)
+            if c.value_sort is None and (' ' in c.value):
+                # Try with the data before a space
+                value = c.value.split(' ')[0]
+                value_sort = comp_match(value, c.ref_prefix)
+                if value_sort is not None:
+                    c.value_sort = value_sort
+                    extra = ', only for sorting purposes' if not cfg.normalize_values else ''
+                    logger.warning(get_last_warning() + "Using `{}` for {} instead{}".format(value, c.ref, extra))
         else:
             c.value_sort = None
         # Try to add the component to an existing group
@@ -421,19 +469,35 @@ def group_components(cfg, components):
         decimal_point = locale.localeconv()['decimal_point']
         if decimal_point == '.':
             decimal_point = None
+    # Coordinates origin for XYRS
+    x_origin = 0.0
+    y_origin = 0.0
+    if cfg.use_aux_axis_as_origin:
+        (x_origin, y_origin) = GS.get_aux_origin()
+        logger.debug('Using auxiliary origin: x={} y={}'.format(x_origin, y_origin))
+    # Process the groups
     for g in groups:
         # Sort the references within each group
         g.sort_components()
         # Fill the columns
-        g.update_fields(cfg.use_alt)
+        g.update_fields(cfg.conv_units, cfg.bottom_negative_x, x_origin, y_origin, cfg.angle_positive,
+                        cfg.footprint_populate_values, cfg.footprint_type_values, cfg.use_alt)
         if cfg.normalize_values:
             g.fields[ColumnList.COL_VALUE_L] = normalize_value(g.components[0], decimal_point)
     # Sort the groups
-    # First priority is the Type of component (e.g. R?, U?, L?)
-    groups = sorted(groups, key=lambda g: [g.components[0].ref_prefix, get_value_sort(g.components[0])])
+    if cfg.sort_style == 'type_value':
+        # First priority is the Type of component (e.g. R?, U?, L?)
+        # Second is the value
+        groups = sorted(groups, key=lambda g: [g.components[0].ref_prefix, get_value_sort(g.components[0])])
+    elif cfg.sort_style == 'type_value_ref':
+        # First priority is the Type of component (e.g. R?, U?, L?)
+        # Second is the value, but if we don't have a value we use the reference
+        groups = sorted(groups, key=lambda g: [g.components[0].ref_prefix, get_value_sort(g.components[0], True)])
+    else:  # ref
+        groups = sorted(groups, key=lambda g: [g.components[0].ref_prefix, _suffix_to_num(g.components[0].ref_suffix)])
     # Enumerate the groups and compute stats
-    n_total = 0
-    n_fitted = 0
+    n_total = n_total_smd = n_total_tht = 0
+    n_fitted = n_fitted_smd = n_fitted_tht = 0
     n_build = 0
     c = 1
     dnf = 1
@@ -449,11 +513,19 @@ def group_components(cfg, components):
         # Stats
         g_l = g.get_count()
         n_total += g_l
+        n_total_smd += g_l*g.is_smd()
+        n_total_tht += g_l*g.is_tht()
         if is_fitted:
             n_fitted += g_l
+            n_fitted_smd += g_l*g.is_smd()
+            n_fitted_tht += g_l*g.is_tht()
             n_build += g.total
     cfg.n_total = n_total
+    cfg.n_total_smd = n_total_smd
+    cfg.n_total_tht = n_total_tht
     cfg.n_fitted = n_fitted
+    cfg.n_fitted_smd = n_fitted_smd
+    cfg.n_fitted_tht = n_fitted_tht
     cfg.n_build = n_build
     if cfg.debug_level > 1:
         logger.debug('Global stats: total {} fitted {} build {}'.format(n_total, n_fitted, n_build))
@@ -463,6 +535,12 @@ def group_components(cfg, components):
     return groups
 
 
+def smd_tht(cfg, tot, smd, tht):
+    if cfg.count_smd_tht:
+        return "{} ({} SMD/ {} THT)".format(tot, smd, tht)
+    return tot
+
+
 def do_bom(file_name, ext, comps, cfg):
     # Group components according to group_fields
     groups = group_components(cfg, comps)
@@ -470,5 +548,13 @@ def do_bom(file_name, ext, comps, cfg):
     logger.debug("Saving BOM File: "+file_name)
     number = cfg.number
     cfg.number = sum(map(lambda prj: prj.number, cfg.aggregate))
+    # Pre-format the total and fitted strings
+    cfg.total_str = smd_tht(cfg, cfg.n_total, cfg.n_total_smd, cfg.n_total_tht)
+    cfg.fitted_str = smd_tht(cfg, cfg.n_fitted, cfg.n_fitted_smd, cfg.n_fitted_tht)
+    if len(cfg.aggregate) > 1:
+        for prj in cfg.aggregate:
+            prj.total_str = smd_tht(cfg, prj.comp_total, prj.comp_total_smd, prj.comp_total_tht)
+            prj.fitted_str = smd_tht(cfg, prj.comp_fitted, prj.comp_fitted_smd, prj.comp_fitted_tht)
+    # Create the BoM
     write_bom(file_name, ext, groups, cfg.columns, cfg)
     cfg.number = number
