@@ -335,16 +335,16 @@ class CfgYamlReader(object):
                             config_error("`import.file` must be a string ({})".format(str(v)))
                         fn = v
                     elif k == 'outputs':
-                        outs = self._parse_import_items('outputs', fn, v)
+                        outs = self._parse_import_items(k, fn, v)
                         explicit_outs = True
                     elif k == 'filters':
-                        filters = self._parse_import_items('filters', fn, v)
+                        filters = self._parse_import_items(k, fn, v)
                         explicit_fils = True
                     elif k == 'variants':
-                        vars = self._parse_import_items('variants', fn, v)
+                        vars = self._parse_import_items(k, fn, v)
                         explicit_vars = True
-                    elif k == 'global':
-                        globals = self._parse_import_items('global', fn, v)
+                    elif k in ['global', 'globals']:
+                        globals = self._parse_import_items(k, fn, v)
                         explicit_globals = True
                     else:
                         self._config_error_import(fn, "unknown import entry `{}`".format(str(v)))
@@ -372,6 +372,10 @@ class CfgYamlReader(object):
             data = yaml.safe_load(fstream)
         except yaml.YAMLError as e:
             config_error("Error loading YAML "+str(e))
+        # Accept `globals` for `global`
+        if 'globals' in data and 'global' not in data:
+            data['global'] = data['globals']
+            del data['globals']
         return data
 
     def read(self, fstream):
@@ -459,7 +463,7 @@ def print_output_options(name, cl, indent):
     ind_str = indent*' '
     obj = cl()
     num_opts = 0
-    for k, v in obj.get_attrs_gen():
+    for k, v in sorted(obj.get_attrs_gen(), key=lambda x: not obj.is_basic_option(x[0])):
         if k == 'type' and indent == 2:
             # Type is fixed for an output
             continue
@@ -467,9 +471,15 @@ def print_output_options(name, cl, indent):
             # We found one, put the title
             print(ind_str+'* Valid keys:')
         help, alias, is_alias = obj.get_doc(k)
+        is_basic = False
+        if help and help[0] == '*':
+            help = help[1:]
+            is_basic = True
         if is_alias:
             help = 'Alias for '+alias
             entry = '  - *{}*: '
+        elif is_basic:
+            entry = '  - **`{}`**: '
         else:
             entry = '  - `{}`: '
         if help is None:
@@ -516,6 +526,11 @@ def print_outputs_help(details=False):
     outs = RegOutput.get_registered()
     logger.debug('{} supported outputs'.format(len(outs)))
     print('Supported outputs:')
+    if details:
+        print('\nNotes:')
+        print('1. Most relevant options are listed first and in **bold**. '
+              'Which ones are more relevant is quite arbitrary, comments are welcome.')
+        print('2. Aliases are listed in *italics*.')
     for n, o in OrderedDict(sorted(outs.items())).items():
         if details:
             print()
@@ -571,7 +586,7 @@ def print_example_options(f, cls, name, indent, po, is_list=False):
     if po:
         obj.read_vals_from_po(po)
     for k, _ in obj.get_attrs_gen():
-        help, alias, is_alias = obj.get_doc(k)
+        help, alias, is_alias = obj.get_doc(k, no_basic=True)
         if is_alias:
             f.write(ind_str+'# `{}` is an alias for `{}`\n'.format(k, alias))
             continue
