@@ -14,7 +14,7 @@ import re
 from sys import exit
 from sys import path as sys_path
 from shutil import which
-from subprocess import run, PIPE
+from subprocess import run, PIPE, Popen
 from glob import glob
 from distutils.version import StrictVersion
 from importlib.util import (spec_from_file_location, module_from_spec)
@@ -68,7 +68,7 @@ def _load_actions(path, load_internals=False):
     lst += glob(os.path.join(path, 'var_*.py')) + glob(os.path.join(path, 'fil_*.py'))
     if load_internals:
         lst += [os.path.join(path, 'globals.py')]
-    for p in lst:
+    for p in sorted(lst):
         name = os.path.splitext(os.path.basename(p))[0]
         logger.debug("- Importing "+name)
         _import(name, p)
@@ -102,6 +102,8 @@ def check_version(command, version):
     if command in script_versions:
         return
     cmd = [command, '--version']
+    if not which(command) and not os.access(command, os.X_OK) and command.endswith('.py'):
+        cmd.insert(0, 'python3')
     logger.debug('Running: '+str(cmd))
     result = run(cmd, stdout=PIPE, stderr=PIPE, universal_newlines=True)
     z = re.match(command + r' (\d+\.\d+\.\d+)', result.stdout, re.IGNORECASE)
@@ -120,7 +122,7 @@ def check_version(command, version):
 
 
 def check_script(cmd, url, version=None):
-    if which(cmd) is None:
+    if which(cmd) is None and not os.path.isfile(cmd):
         logger.error('No `'+cmd+'` command found.\n'
                      'Please install it, visit: '+url)
         logger.error(TRY_INSTALL_CHECK)
@@ -324,7 +326,7 @@ def get_board_comps_data(comps):
                 c.virtual = True
 
 
-def preflight_checks(skip_pre):
+def preflight_checks(skip_pre, targets):
     logger.debug("Preflight checks")
 
     if skip_pre is not None:
@@ -348,7 +350,7 @@ def preflight_checks(skip_pre):
                     else:
                         logger.debug('Skipping `{}`'.format(skip))
                         o_pre.disable()
-    BasePreFlight.run_enabled()
+    BasePreFlight.run_enabled(targets)
 
 
 def get_output_dir(o_dir, obj, dry=False):
@@ -409,44 +411,63 @@ def run_output(out, dont_stop=False):
             raise
 
 
-def generate_outputs(outputs, target, invert, skip_pre, cli_order, dont_stop=False):
+def generate_outputs(outputs, targets, invert, skip_pre, cli_order, no_priority, dont_stop=False):
     logger.debug("Starting outputs for board {}".format(GS.pcb_file))
-    preflight_checks(skip_pre)
-    # Check if the preflights pulled options
-    for out in RegOutput.get_prioritary_outputs():
+    # Make a list of target outputs
+    n = len(targets)
+    if n == 0:
+        # No targets means all
+        if invert:
+            # Skip all targets
+            logger.debug('Skipping all outputs')
+        else:
+            targets = [out for out in RegOutput.get_outputs() if out.run_by_default]
+    else:
+        # Check we got a valid list of outputs
+        for name in targets:
+            out = RegOutput.get_output(name)
+            if out is None:
+                logger.error('Unknown output `{}`'.format(name))
+                exit(EXIT_BAD_ARGS)
+        # Check for CLI+invert inconsistency
+        if cli_order and invert:
+            logger.error("CLI order and invert options can't be used simultaneously")
+            exit(EXIT_BAD_ARGS)
+        # Now convert the list of names into a list of output objects
+        if cli_order:
+            # Add them in the same order found at the command line
+            targets = [RegOutput.get_output(name) for name in targets]
+        else:
+            # Add them in the declared order
+            new_targets = []
+            if invert:
+                # Invert the selection
+                for out in RegOutput.get_outputs():
+                    if (out.name not in targets) and out.run_by_default:
+                        new_targets.append(out)
+                    else:
+                        logger.debug('Skipping `{}` output'.format(out.name))
+            else:
+                # Normal list
+                for out in RegOutput.get_outputs():
+                    if out.name in targets:
+                        new_targets.append(out)
+                    else:
+                        logger.debug('Skipping `{}` output'.format(out.name))
+            targets = new_targets
+    logger.debug('Outputs before preflights: {}'.format(targets))
+    # Run the preflights
+    preflight_checks(skip_pre, targets)
+    logger.debug('Outputs after preflights: {}'.format(targets))
+    if not cli_order and not no_priority:
+        # Sort by priority
+        targets = sorted(targets, key=lambda o: o.priority, reverse=True)
+        logger.debug('Outputs after sorting: {}'.format(targets))
+    # Configure and run the outputs
+    for out in targets:
         if config_output(out, dont_stop=dont_stop):
             logger.info('- '+str(out))
-            run_output(out, dont_stop=dont_stop)
-    # Check if all must be skipped
-    n = len(target)
-    if n == 0 and invert:
-        # Skip all targets
-        logger.debug('Skipping all outputs')
-        return
-    # Check we got a valid list of outputs
-    for name in target:
-        out = RegOutput.get_output(name)
-        if out is None:
-            logger.error('Unknown output `{}`'.format(name))
-            exit(EXIT_BAD_ARGS)
-    # Generate outputs
-    if cli_order and not invert:
-        # Use the CLI order
-        for name in target:
-            out = RegOutput.get_output(name)
-            if config_output(out, dont_stop=dont_stop):
-                logger.info('- '+str(out))
-                run_output(out, dont_stop)
-    else:
-        # Use the declaration order
-        for out in RegOutput.get_outputs():
-            if (((n == 0 or ((out.name not in target) and invert)) and out.run_by_default) or
-               ((out.name in target) and not invert)):
-                if config_output(out, dont_stop=dont_stop):
-                    logger.info('- '+str(out))
-                    run_output(out, dont_stop)
-            else:
-                logger.debug('Skipping `%s` output', str(out))
+            run_output(out, dont_stop)
 
 
 def adapt_file_name(name):
@@ -767,6 +788,14 @@ def discover_files(dest_dir):
     return fname
 
 
+def yaml_dump(f, tree):
+    if StrictVersion(yaml.__version__) < StrictVersion('3.14'):
+        f.write(yaml.dump(tree))
+    else:
+        # sort_keys was introduced after 3.13
+        f.write(yaml.dump(tree, sort_keys=False))
+
+
 def generate_one_example(dest_dir, types):
     """ Generate a example config for dest_dir """
     fname = discover_files(dest_dir)
@@ -797,21 +826,21 @@ def generate_one_example(dest_dir, types):
                {'number': 58},    # Missing project file
                ]
         glb = {'filters': fil}
-        f.write(yaml.dump({'global': glb}, sort_keys=False))
+        yaml_dump(f, {'global': glb})
         f.write('\n')
         # A helper for the JLCPCB stuff
         fil = {'name': 'only_jlc_parts'}
         fil['comment'] = 'Only parts with JLC (LCSC) code'
         fil['type'] = 'generic'
         fil['include_only'] = [{'column': 'LCSC#', 'regex': r'^C\d+'}]
-        f.write(yaml.dump({'filters': [fil]}, sort_keys=False))
+        yaml_dump(f, {'filters': [fil]})
         f.write('\n')
         # A helper for KiCost demo
         var = {'name': 'place_holder'}
         var['comment'] = 'Just a place holder for pre_transform filters'
         var['type'] = 'kicost'
         var['pre_transform'] = ['_kicost_rename', '_rot_footprint']
-        f.write(yaml.dump({'variants': [var]}, sort_keys=False))
+        yaml_dump(f, {'variants': [var]})
         f.write('\n')
         # All the outputs
         outputs = []
@@ -839,7 +868,7 @@ def generate_one_example(dest_dir, types):
             else:
                 logger.debug('- {}, nothing to do'.format(n))
         if outputs:
-            f.write(yaml.dump({'outputs': outputs}, sort_keys=False))
+            yaml_dump(f, {'outputs': outputs})
         else:
             return None
     return fname
@@ -857,7 +886,7 @@ def generate_targets(config_file):
     with open(config_file) as cf_file:
         outputs = cr.read(cf_file)
     # Do all the job
-    generate_outputs(outputs, [], False, None, False, dont_stop=True)
+    generate_outputs(outputs, [], False, None, False, False, dont_stop=True)
 
 
 def _walk(path, depth):
@@ -926,6 +955,9 @@ def generate_examples(start_dir, dry, types):
         log.remove_file_log(fl)
         GS.debug_level = old_lvl
         logger.info('')
+    # Try to open a browser
+    if os.environ.get('DISPLAY') and which('x-www-browser'):
+        Popen(['x-www-browser', os.path.join(GS.out_dir, 'index.html')])
 
 
 # To avoid circular dependencies: Optionable needs it, but almost everything needs Optionable
