@@ -6,13 +6,13 @@
 import os
 from shutil import rmtree
 from .pre_base import BasePreFlight
-from .error import KiPlotConfigurationError
 from .gs import GS
 from .kiplot import check_script, exec_with_retry, add_extra_options
 from .misc import CMD_PCBNEW_PRINT_LAYERS, URL_PCBNEW_PRINT_LAYERS, PDF_PCB_PRINT, kiauto_dependency
 from .out_base import VariantOptions
 from .registrable import RegDependency
 from .macros import macros, document, output_class  # noqa: F401
+from .drill_marks import add_drill_marks, DRILL_MARKS_MAP
 from .layer import Layer
 from . import log
 
@@ -24,23 +24,18 @@ def register_deps(pre):
 
 
 class Any_PCB_PrintOptions(VariantOptions):
-    # Mappings to KiCad config values. They should be the same used in drill_marks.py
-    _drill_marks_map = {'none': 0, 'small': 1, 'full': 2}
-
     def __init__(self):
         with document:
             self.output_name = None
             """ {output} """
             self.scaling = 1.0
-            """ Scale factor (0 means autoscaling)"""
-            self._drill_marks = 'full'
-            """ What to use to indicate the drill places, can be none, small or full (for real scale) """
+            """ *Scale factor (0 means autoscaling). You should disable `plot_sheet_reference` when using it """
             self.plot_sheet_reference = True
-            """ Include the title-block """
+            """ *Include the title-block """
             self.monochrome = False
             """ Print in black and white """
             self.separated = False
-            """ Print layers in separated pages """
+            """ *Print layers in separated pages """
             self.mirror = False
             """ Print mirrored (X axis inverted). ONLY for KiCad 6 """
             self.hide_excluded = False
@@ -56,21 +51,12 @@ class Any_PCB_PrintOptions(VariantOptions):
             """ Selects the color theme. Onlyu applies to KiCad 6.
                 To use the KiCad 6 default colors select `_builtin_default`.
                 Usually user colors are stored as `user`, but you can give it another name """
+        add_drill_marks(self)
         super().__init__()
 
-    @property
-    def drill_marks(self):
-        return self._drill_marks
-
-    @drill_marks.setter
-    def drill_marks(self, val):
-        if val not in self._drill_marks_map:
-            raise KiPlotConfigurationError("Unknown drill mark type: {}".format(val))
-        self._drill_marks = val
-
     def config(self, parent):
         super().config(parent)
-        self._drill_marks = Any_PCB_PrintOptions._drill_marks_map[self._drill_marks]
+        self.drill_marks = DRILL_MARKS_MAP[self.drill_marks]
 
     def filter_components(self, board, force_copy):
         if not self._comps and not force_copy:
@@ -98,7 +84,7 @@ class Any_PCB_PrintOptions(VariantOptions):
         cmd = [CMD_PCBNEW_PRINT_LAYERS, 'export', '--output_name', output]
         if BasePreFlight.get_option('check_zone_fills'):
             cmd.append('-f')
-        cmd.extend(['--scaling', str(self.scaling), '--pads', str(self._drill_marks)])
+        cmd.extend(['--scaling', str(self.scaling), '--pads', str(self.drill_marks)])
         if not self.plot_sheet_reference:
             cmd.append('--no-title')
         if self.monochrome:
