@@ -20,7 +20,7 @@ class GenCADOptions(BaseOptions):
     def __init__(self):
         with document:
             self.output = GS.def_global_output
-            """ Filename for the output (%i=gencad, %x=cad) """
+            """ *Filename for the output (%i=gencad, %x=cad) """
             self.flip_bottom_padstacks = False
             """ Flip bottom footprint padstacks """
             self.unique_pin_names = False
@@ -35,6 +35,9 @@ class GenCADOptions(BaseOptions):
         self._expand_id = 'gencad'
         self._expand_ext = 'cad'
 
+    def get_targets(self, out_dir):
+        return [self._parent.expand_filename(out_dir, self.output)]
+
     def run(self, name):
         check_script(CMD_PCBNEW_GENCAD, URL_PCBNEW_GENCAD, '1.6.5')
         # Output file name
@@ -70,9 +73,10 @@ class GenCAD(BaseOutput):  # noqa: F821
         manufacturers """
     def __init__(self):
         super().__init__()
+        self._category = 'PCB/export'
         with document:
             self.options = GenCADOptions
-            """ [dict] Options for the `gencad` output """
+            """ *[dict] Options for the `gencad` output """
 
     @staticmethod
     def get_conf_examples(name, layers, templates):
