@@ -5,6 +5,7 @@
 # Project: KiBot (formerly KiPlot)
 import os
 from subprocess import (check_output, STDOUT, CalledProcessError)
+from shutil import which
 from .misc import (CMD_IBOM, URL_IBOM, BOM_ERROR, W_EXTNAME, ToolDependency, ToolDependencyRole, W_NONETLIST)
 from .gs import (GS)
 from .kiplot import check_script, search_as_plugin
@@ -15,14 +16,15 @@ from . import log
 
 logger = log.get_logger()
 WARNING_MIX = "Avoid using it in conjunction with IBoM native filtering options"
+PLUGIN_NAMES = ['InteractiveHtmlBom', 'InteractiveHtmlBom/InteractiveHtmlBom',
+                'org_openscopeproject_InteractiveHtmlBom/InteractiveHtmlBom']
 RegDependency.register(ToolDependency('ibom', 'Interactive HTML BoM', URL_IBOM, url_down=URL_IBOM+'/releases',
                                       command=CMD_IBOM, in_debian=False, no_cmd_line_version_old=True,
-                                      plugin_dirs=['InteractiveHtmlBom', 'InteractiveHtmlBom/InteractiveHtmlBom'],
-                                      roles=ToolDependencyRole(version=(2, 4, 1, 4))))
+                                      plugin_dirs=PLUGIN_NAMES, roles=ToolDependencyRole(version=(2, 4, 1, 4))))
 
 
 def check_tool():
-    tool = search_as_plugin(CMD_IBOM, ['InteractiveHtmlBom', 'InteractiveHtmlBom/InteractiveHtmlBom'])
+    tool = search_as_plugin(CMD_IBOM, PLUGIN_NAMES)
     check_script(tool, URL_IBOM)
     return tool
 
@@ -31,7 +33,7 @@ class IBoMOptions(VariantOptions):
     def __init__(self):
         with document:
             self.output = GS.def_global_output
-            """ Filename for the output, use '' to use the IBoM filename (%i=ibom, %x=html) """
+            """ *Filename for the output, use '' to use the IBoM filename (%i=ibom, %x=html) """
             self.dark_mode = False
             """ Default to dark mode """
             self.hide_pads = False
@@ -45,13 +47,13 @@ class IBoMOptions(VariantOptions):
             self.no_redraw_on_drag = False
             """ Do not redraw pcb on drag by default """
             self.board_rotation = 0
-            """ Board rotation in degrees (-180 to 180). Will be rounded to multiple of 5 """
+            """ *Board rotation in degrees (-180 to 180). Will be rounded to multiple of 5 """
             self.checkboxes = 'Sourced,Placed'
             """ Comma separated list of checkbox columns """
             self.bom_view = 'left-right'
-            """ [bom-only,left-right,top-bottom] Default BOM view """
+            """ *[bom-only,left-right,top-bottom] Default BOM view """
             self.layer_view = 'FB'
-            """ [F,FB,B] Default layer view """
+            """ *[F,FB,B] Default layer view """
             self.no_compression = False
             """ Disable compression of pcb data """
             self.name_format = 'ibom'
@@ -66,7 +68,7 @@ class IBoMOptions(VariantOptions):
                 Extension .html will be added automatically.
                 Note that this name is used only when output is '' """
             self.include_tracks = False
-            """ Include track/zone information in output. F.Cu and B.Cu layers only """
+            """ *Include track/zone information in output. F.Cu and B.Cu layers only """
             self.include_nets = False
             """ Include netlist information in output. """
             self.sort_order = 'C,R,L,D,U,Y,X,F,SW,A,~,HS,CNN,J,P,NT,MH'
@@ -77,16 +79,16 @@ class IBoMOptions(VariantOptions):
             """ Path to netlist or xml file. You can use '%F.xml' to avoid specifying the project name.
                 Leave it blank for most uses, data will be extracted from the PCB """
             self.extra_fields = ''
-            """ Comma separated list of extra fields to pull from netlist or xml file.
+            """ *Comma separated list of extra fields to pull from netlist or xml file.
                 Using 'X,Y' is a shortcut for `show_fields` and `group_fields` with values 'Value,Footprint,X,Y' """
             self.show_fields = ''
-            """ Comma separated list of fields to show in the BOM.
+            """ *Comma separated list of fields to show in the BOM.
                 Value and Footprint are displayed when nothing is specified """
             self.group_fields = ''
             """ Comma separated list of fields that components will be grouped by.
                 Value and Footprint are used when nothing is specified """
             self.normalize_field_case = False
-            """ Normalize extra field name case. E.g. 'MPN' and 'mpn' will be considered the same field """
+            """ *Normalize extra field name case. E.g. 'MPN' and 'mpn' will be considered the same field """
             self.blacklist = ''
             """ List of comma separated blacklisted components or prefixes with *. E.g. 'X1,MH*'.
                 IBoM option, avoid using in conjunction with KiBot variants/filters """
@@ -161,6 +163,9 @@ class IBoMOptions(VariantOptions):
         else:
             output_dir = name
         cmd = [tool, GS.pcb_file, '--dest-dir', output_dir, '--no-browser', ]
+        if not which(tool) and not os.access(tool, os.X_OK):
+            # Plugin could be installed without execute flags
+            cmd.insert(0, 'python3')
         # Check if the user wants extra_fields but there is no data about them (#68)
         if self.need_extra_fields() and not os.path.isfile(self.extra_data_file):
             logger.warning(W_NONETLIST+'iBoM needs information about user defined fields and no netlist provided')
@@ -213,7 +218,7 @@ class IBoM(BaseOutput):  # noqa: F821
         super().__init__()
         with document:
             self.options = IBoMOptions
-            """ [dict] Options for the `ibom` output """
+            """ *[dict] Options for the `ibom` output """
 
     def get_dependencies(self):
         return self.options.get_dependencies()
