@@ -28,6 +28,7 @@ from .kiplot import check_script, exec_with_retry, add_extra_options
 from .registrable import RegDependency
 from .create_pdf import create_pdf_from_pages
 from .macros import macros, document, output_class  # noqa: F401
+from .drill_marks import DRILL_MARKS_MAP, add_drill_marks
 from .layer import Layer, get_priority
 from . import __version__
 from . import log
@@ -178,7 +179,7 @@ class PagesOptions(Optionable):
             self.monochrome = False
             """ Print in gray scale """
             self.scaling = None
-            """ [number=1.0] Scale factor (0 means autoscaling)"""
+            """ *[number=1.0] Scale factor (0 means autoscaling)"""
             self.title = ''
             """ Text used to replace the sheet title. %VALUE expansions are allowed.
                 If it starts with `+` the text is concatenated """
@@ -199,9 +200,9 @@ class PagesOptions(Optionable):
             self.holes_color = '#000000'
             """ Color used for the holes when `colored_holes` is enabled """
             self.sort_layers = False
-            """ Try to sort the layers in the same order that uses KiCad for printing """
+            """ *Try to sort the layers in the same order that uses KiCad for printing """
             self.layers = LayerOptions
-            """ [list(dict)|list(string)|string] List of layers printed in this page.
+            """ *[list(dict)|list(string)|string] List of layers printed in this page.
                 Order is important, the last goes on top """
         self._scaling_example = 1.0
 
@@ -223,7 +224,6 @@ class PagesOptions(Optionable):
 
 class PCB_PrintOptions(VariantOptions):
     # Mappings to KiCad config values. They should be the same used in drill_marks.py
-    _drill_marks_map = {'none': 0, 'small': 1, 'full': 2}
     _pad_colors = {'pad_color': 'pad_through_hole',
                    'via_color': 'via_through',
                    'micro_via_color': 'via_micro',
@@ -234,17 +234,15 @@ class PCB_PrintOptions(VariantOptions):
             self.output_name = None
             """ {output} """
             self.output = GS.def_global_output
-            """ Filename for the output (%i=assembly, %x=pdf)/(%i=assembly_page_NN, %x=svg)"""
+            """ *Filename for the output (%i=assembly, %x=pdf)/(%i=assembly_page_NN, %x=svg)"""
             self.hide_excluded = False
             """ Hide components in the Fab layer that are marked as excluded by a variant """
-            self._drill_marks = 'full'
-            """ What to use to indicate the drill places, can be none, small or full (for real scale) """
             self.color_theme = '_builtin_classic'
-            """ Selects the color theme. Only applies to KiCad 6.
+            """ *Selects the color theme. Only applies to KiCad 6.
                 To use the KiCad 6 default colors select `_builtin_default`.
                 Usually user colors are stored as `user`, but you can give it another name """
             self.plot_sheet_reference = True
-            """ Include the title-block (worksheet, frame, etc.) """
+            """ *Include the title-block (worksheet, frame, etc.) """
             self.sheet_reference_layout = ''
             """ Worksheet file (.kicad_wks) to use. Leave empty to use the one specified in the project """
             self.frame_plot_mechanism = 'internal'
@@ -257,13 +255,13 @@ class PCB_PrintOptions(VariantOptions):
                 plot: uses KiCad Python API. Only available for KiCad 6.
                 You get the default frame and some substitutions doesn't work """
             self.pages = PagesOptions
-            """ [list(dict)] List of pages to include in the output document.
+            """ *[list(dict)] List of pages to include in the output document.
                 Each page contains one or more layers of the PCB """
             self.title = ''
             """ Text used to replace the sheet title. %VALUE expansions are allowed.
                 If it starts with `+` the text is concatenated """
             self.format = 'PDF'
-            """ [PDF,SVG,PNG,EPS,PS] Format for the output file/s.
+            """ *[PDF,SVG,PNG,EPS,PS] Format for the output file/s.
                 Note that for PS you need `ghostscript` which isn't part of the default docker images """
             self.png_width = 1280
             """ Width of the PNG in pixels """
@@ -282,9 +280,9 @@ class PCB_PrintOptions(VariantOptions):
             self.keep_temporal_files = False
             """ Store the temporal page and layer files in the output dir and don't delete them """
             self.force_edge_cuts = False
-            """ Add the `Edge.Cuts` to all the pages """
+            """ *Add the `Edge.Cuts` to all the pages """
             self.scaling = 1.0
-            """ Default scale factor (0 means autoscaling)"""
+            """ *Default scale factor (0 means autoscaling)"""
             self.realistic_solder_mask = True
             """ Try to draw the solder mask as a real solder mask, not the negative used for fabrication.
                 In order to get a good looking select a color with transparency, i.e. '#14332440'.
@@ -295,19 +293,10 @@ class PCB_PrintOptions(VariantOptions):
             """ Color for the background when `add_background` is enabled """
             self.background_image = ''
             """ Background image, must be an SVG, only when `add_background` is enabled """
+        add_drill_marks(self)
         super().__init__()
         self._expand_id = 'assembly'
 
-    @property
-    def drill_marks(self):
-        return self._drill_marks
-
-    @drill_marks.setter
-    def drill_marks(self, val):
-        if val not in self._drill_marks_map:
-            raise KiPlotConfigurationError("Unknown drill mark type: {}".format(val))
-        self._drill_marks = val
-
     def config(self, parent):
         super().config(parent)
         if isinstance(self.pages, type):
@@ -324,7 +313,7 @@ class PCB_PrintOptions(VariantOptions):
                         la.color = layer_id2color[la._id]
                     else:
                         la.color = "#000000"
-        self._drill_marks = PCB_PrintOptions._drill_marks_map[self._drill_marks]
+        self.drill_marks = DRILL_MARKS_MAP[self.drill_marks]
         self._expand_ext = self.format.lower()
         for member, color in self._pad_colors.items():
             if getattr(self, member):
@@ -487,7 +476,8 @@ class PCB_PrintOptions(VariantOptions):
             video_name = os.path.join(self.expand_filename_pcb(GS.out_dir), 'pcbnew_export_screencast.ogv')
             if os.path.isfile(video_name):
                 os.remove(video_name)
-        patch_svg_file(output, remove_bkg=True)
+        # Rotate the paper size if needed and remove the background (or it will be over the drawings)
+        patch_svg_file(output, remove_bkg=True, is_portrait=self.paper_portrait)
 
     def plot_pads(self, la, pc, p, filelist):
         id = la._id
@@ -744,7 +734,6 @@ class PCB_PrintOptions(VariantOptions):
                 scale = base_width/width
                 if scale != 1.0:
                     logger.debug(' - Scaling {} by {}'.format(file, scale))
-                    logger.error('Este')
                     for e in root:
                         e.scale(scale)
                 svg_out.append([root])
@@ -754,6 +743,7 @@ class PCB_PrintOptions(VariantOptions):
         pcb = PCB.load(GS.pcb_file)
         self.paper_w = pcb.paper_w
         self.paper_h = pcb.paper_h
+        self.paper_portrait = pcb.paper_portrait
         self.paper = pcb.paper
 
     def plot_extra_cu(self, id, la, pc, p, filelist):
@@ -761,7 +751,6 @@ class PCB_PrintOptions(VariantOptions):
         if id >= F_Cu and id <= B_Cu:
             if self.colored_pads:
                 self.plot_pads(la, pc, p, filelist)
-            return
             if self.colored_vias:
                 self.plot_vias(la, pc, p, filelist, VIATYPE_THROUGH, self.via_color)
                 self.plot_vias(la, pc, p, filelist, VIATYPE_BLIND_BURIED, self.blind_via_color)
@@ -938,7 +927,7 @@ class PCB_PrintOptions(VariantOptions):
                 po.SetPlotValue(la.plot_footprint_values)
                 po.SetPlotInvisibleText(la.force_plot_invisible_refs_vals)
                 # Avoid holes on non-copper layers
-                po.SetDrillMarksType(self._drill_marks if IsCopperLayer(id) else 0)
+                po.SetDrillMarksType(self.drill_marks if IsCopperLayer(id) else 0)
                 pc.SetLayer(id)
                 pc.OpenPlotfile(la.suffix, PLOT_FORMAT_SVG, p.sheet)
                 pc.PlotLayer()
@@ -1007,7 +996,8 @@ class PCB_Print(BaseOutput):  # noqa: F821
         super().__init__()
         with document:
             self.options = PCB_PrintOptions
-            """ [dict] Options for the `pcb_print` output """
+            """ *[dict] Options for the `pcb_print` output """
+        self._category = 'PCB/docs'
 
     @staticmethod
     def get_conf_examples(name, layers, templates):
