@@ -34,10 +34,11 @@ class PDF_PCB_Print(BaseOutput):  # noqa: F821
         super().__init__()
         with document:
             self.options = PDF_PCB_PrintOptions
-            """ [dict] Options for the `pdf_pcb_print` output """
+            """ *[dict] Options for the `pdf_pcb_print` output """
             self.layers = Layer
-            """ [list(dict)|list(string)|string] [all,selected,copper,technical,user]
+            """ *[list(dict)|list(string)|string] [all,selected,copper,technical,user]
                 List of PCB layers to include in the PDF """
+        self._category = 'PCB/docs'
 
     def config(self, parent):
         super().config(parent)
