@@ -16,7 +16,7 @@ from .macros import macros, document, output_class  # noqa: F401
 from . import log
 
 logger = log.get_logger()
-RegDependency.register(kiauto_dependency('render_3d', (1, 6, 8)))
+RegDependency.register(kiauto_dependency('render_3d', (1, 6, 13)))
 
 
 class Render3DOptions(Base3DOptions):
@@ -33,7 +33,7 @@ class Render3DOptions(Base3DOptions):
     def __init__(self):
         with document:
             self.output = GS.def_global_output
-            """ Name for the generated image file (%i='3D_$VIEW' %x='png') """
+            """ *Name for the generated image file (%i='3D_$VIEW' %x='png') """
             self.no_tht = False
             """ Used to exclude 3D models for through hole components """
             self.no_smd = False
@@ -53,31 +53,33 @@ class Render3DOptions(Base3DOptions):
             self.solder_paste = "#808080"
             """ Color for the solder paste """
             self.move_x = 0
-            """ Steps to move in the X axis, positive is to the right.
+            """ *Steps to move in the X axis, positive is to the right.
                 Just like pressing the right arrow in the 3D viewer """
             self.move_y = 0
-            """ Steps to move in the Y axis, positive is up.
+            """ *Steps to move in the Y axis, positive is up.
                 Just like pressing the up arrow in the 3D viewer """
             self.rotate_x = 0
-            """ Steps to rotate around the X axis, positive is clockwise.
+            """ *Steps to rotate around the X axis, positive is clockwise.
                 Each step is currently 10 degrees. Only for KiCad 6 """
             self.rotate_y = 0
-            """ Steps to rotate around the Y axis, positive is clockwise.
+            """ *Steps to rotate around the Y axis, positive is clockwise.
                 Each step is currently 10 degrees. Only for KiCad 6 """
             self.rotate_z = 0
-            """ Steps to rotate around the Z axis, positive is clockwise.
+            """ *Steps to rotate around the Z axis, positive is clockwise.
                 Each step is currently 10 degrees. Only for KiCad 6 """
             self.ray_tracing = False
-            """ Enable the ray tracing. Much better result, but slow, and you'll need to adjust `wait_rt` """
-            self.wait_ray_tracing = -600
-            """ How many seconds we must wait before capturing the ray tracing render.
+            """ *Enable the ray tracing. Much better result, but slow, and you'll need to adjust `wait_rt` """
+            self.wait_render = -600
+            """ How many seconds we must wait before capturing the render (ray tracing or normal).
                 Lamentably KiCad can save an unfinished image. Enlarge it if your image looks partially rendered.
                 Use negative values to enable the auto-detect using CPU load.
                 In this case the value is interpreted as a time-out. """
+            self.wait_ray_tracing = None
+            """ {wait_render} """
             self.view = 'top'
-            """ [top,bottom,front,rear,right,left,z,Z,y,Y,x,X] Point of view """
+            """ *[top,bottom,front,rear,right,left,z,Z,y,Y,x,X] Point of view """
             self.zoom = 0
-            """ Zoom steps. Use positive to enlarge, get closer, and negative to reduce.
+            """ *Zoom steps. Use positive to enlarge, get closer, and negative to reduce.
                 Same result as using the mouse wheel in the 3D viewer """
             self.width = 1280
             """ Image width (aprox.) """
@@ -141,7 +143,7 @@ class Render3DOptions(Base3DOptions):
             logger.error("3D Viewer not supported for KiCad 6.0.0/1\n"
                          "Please upgrade KiCad to 6.0.2 or newer")
             exit(MISSING_TOOL)
-        check_script(CMD_PCBNEW_3D, URL_PCBNEW_3D, '1.6.8')
+        check_script(CMD_PCBNEW_3D, URL_PCBNEW_3D, '1.6.13')
         # Base command with overwrite
         cmd = [CMD_PCBNEW_3D, '--rec_w', str(self.width+2), '--rec_h', str(self.height+85),
                '3d_view', '--output_name', output]
@@ -161,11 +163,11 @@ class Render3DOptions(Base3DOptions):
         self.add_step(cmd, self.rotate_z, '--rotate_z')
         if self.zoom:
             cmd.extend(['--zoom', str(self.zoom)])
-        if self.wait_ray_tracing != 5:
-            if self.wait_ray_tracing < 0:
-                self.wait_ray_tracing = -self.wait_ray_tracing
+        if self.wait_render != 5:
+            if self.wait_render < 0:
+                self.wait_render = -self.wait_render
                 cmd.append('--detect_rt')
-            cmd.extend(['--wait_rt', str(self.wait_ray_tracing)])
+            cmd.extend(['--wait_rt', str(self.wait_render), '--use_rt_wait'])
         if self.ray_tracing:
             cmd.append('--ray_tracing')
         if self.orthographic:
@@ -200,7 +202,8 @@ class Render_3D(Base3D):  # noqa: F821
         super().__init__()
         with document:
             self.options = Render3DOptions
-            """ [dict] Options for the `render_3d` output """
+            """ *[dict] Options for the `render_3d` output """
+        self._category = 'PCB/3D'
 
     @staticmethod
     def get_conf_examples(name, layers, templates):
