@@ -8,6 +8,7 @@ from .gs import GS
 from .out_any_pcb_print import Any_PCB_PrintOptions, register_deps
 from .error import KiPlotConfigurationError
 from .kicad.patch_svg import patch_svg_file
+from .kicad.pcb import PCB
 from .macros import macros, document, output_class  # noqa: F401
 from .layer import Layer
 from . import log
@@ -20,7 +21,7 @@ class SVG_PCB_PrintOptions(Any_PCB_PrintOptions):
     def __init__(self):
         with document:
             self.output = GS.def_global_output
-            """ Filename for the output SVG (%i=layers, %x=svg)"""
+            """ *Filename for the output SVG (%i=layers, %x=svg)"""
             self.enable_ki6_page_fix = True
             """ Enable workaround for KiCad 6 bug #11033 """
             self.enable_ki5_page_fix = True
@@ -34,8 +35,9 @@ class SVG_PCB_PrintOptions(Any_PCB_PrintOptions):
             # KiCad 6.0.2 bug: https://gitlab.com/kicad/code/kicad/-/issues/11033
             o = self._parent
             out_files = o.get_targets(o.expand_dirname(os.path.join(GS.out_dir, o.dir)))
+            is_portrait = PCB.load(GS.pcb_file).paper_portrait
             for file in out_files:
-                patch_svg_file(file)
+                patch_svg_file(file, is_portrait=is_portrait)
 
 
 @output_class
@@ -48,10 +50,11 @@ class SVG_PCB_Print(BaseOutput):  # noqa: F821
         super().__init__()
         with document:
             self.options = SVG_PCB_PrintOptions
-            """ [dict] Options for the `pdf_pcb_print` output """
+            """ *[dict] Options for the `pdf_pcb_print` output """
             self.layers = Layer
-            """ [list(dict)|list(string)|string] [all,selected,copper,technical,user]
+            """ *[list(dict)|list(string)|string] [all,selected,copper,technical,user]
                 List of PCB layers to include in the PDF """
+        self._category = 'PCB/docs'
 
     def config(self, parent):
         super().config(parent)
