@@ -33,8 +33,9 @@ class SVG_SCH_Print(BaseOutput):  # noqa: F821
         super().__init__()
         with document:
             self.options = SVG_SCH_PrintOptions
-            """ [dict] Options for the `svg_sch_print` output """
+            """ *[dict] Options for the `svg_sch_print` output """
         self._sch_related = True
+        self._category = 'Schematic/docs'
 
     @staticmethod
     def get_conf_examples(name, layers, templates):
